#!/bin/bash

export LOGFILE='/var/log/ngcp-installer.log'
exec  > >(tee -a "${LOGFILE}"    )
exec 2> >(tee -a "${LOGFILE}" >&2)

if ${CARRIER} ; then
  export NGCP_TYPE=carrier
  export SIPWISE_REPO_TYPE=sppro
elif ${PRO} ; then
  export NGCP_TYPE=sppro
  export SIPWISE_REPO_TYPE=sppro
else
  export NGCP_TYPE=spce
  export SIPWISE_REPO_TYPE=spce
fi

export FILEPATH="/usr/share/ngcp-installer"
export CONFIGPATH="/etc/ngcp-config"
export CFG_SCHEMA_FILE="${CONFIGPATH}/cfg_schema.db"
export CONFIG_YML="${CONFIGPATH}/config.yml"
export CONSTANTS_YML="${CONFIGPATH}/constants.yml"
export MAINTENANCE_YML="${CONFIGPATH}/maintenance.yml"
export NETWORK_YML="${CONFIGPATH}/network.yml"
export NGCPCFG_BASE="${CONFIGPATH}/cfg_schema.db"
export SIPWISE_EXTRA_CNF="/etc/mysql/sipwise_extra.cnf"

declare -a APT_ENV=()
declare -a APT_PARAMS=()
APT_PARAMS+=("--no-install-recommends")
APT_PARAMS+=("--yes")
APT_PARAMS+=("-o DPkg::Options::=--force-confask")
APT_PARAMS+=("-o DPkg::Options::=--force-confdef")
APT_PARAMS+=("-o DPkg::Options::=--force-confmiss")
APT_PARAMS+=("-o DPkg::Options::=--force-confnew")
export APT_ENV
export APT_PARAMS

export CDRUSER="cdrexport"
export BACKUPUSER="ngcp-backup"
export INNODB_BUFFER_POOL_FACTOR="0.5"

export DEBIAN_FRONTEND=noninteractive

if "${CARRIER}" || "${PRO}"; then
  NGCP_METAPACKAGE="ngcp-ngcp-pro"
else
  NGCP_METAPACKAGE="ngcp-ngcp-ce"
fi
export NGCP_METAPACKAGE

export CERT_PATH="/etc/ngcp-config/shared-files/ssl"
CERT_USERS="www-data prosody kamailio"
if ${PRO} || ${CARRIER} ; then
  CERT_USERS="${CERT_USERS} openldap"
fi
export CERT_USERS

# set peer replication
export DPL_MYSQL_REPLICATION=true

declare -a ETCKEEPER_IGNORE=()
ETCKEEPER_IGNORE+=("/etc/check_mk/cache")
export ETCKEEPER_IGNORE

DEBIAN_VERSION=''
DEBIAN_CODENAME=''
if [[ "$(cat /etc/debian_version)" =~ 11|bullseye ]]; then
  DEBIAN_VERSION=11
  DEBIAN_CODENAME='bullseye'
elif [[ "$(cat /etc/debian_version)" =~ 12|bookworm ]]; then
  DEBIAN_VERSION=12
  DEBIAN_CODENAME='bookworm'
fi
export DEBIAN_VERSION
export DEBIAN_CODENAME

export NGCP_DEBIAN_CURRENT_VERSION=11
export NGCP_DEBIAN_CURRENT_CODENAME=bullseye
export NGCP_DEBIAN_NEXT_CODENAME=bookworm

export UPGRADE_MODE="${UPGRADE_MODE:-false}"

export STEPS_DIR="/ngcp-data/ngcp-initial-configuration/steps"

export SHARED_NAME='sp'
