#!/bin/bash

enable_vm_services() {
  if ! "${ENABLE_VM_SERVICES:-false}" ; then
    log_info "No need to enable any VM services here"
    return
  fi

  if ${PRO} || ${CARRIER} ; then
    log_info "Enabling:"
    log_info "  presence for PRO/Carrier installations"
    log_info "  debug for netscript PRO/Carrier installation only"
    log_info "  voisniff for PRO/Carrier installations"  
    log_info "  fileshare for PRO/Carrier installation only"  

    ngcpcfg set "${CONFIG_YML}" \
      "kamailio.proxy.presence.enable=yes" \
      "bootenv.netscript.debug=yes" \
      "voisniff.admin_panel=yes" \
      "voisniff.daemon.start=yes" \
      "voisniff.daemon.mysql_dump.num_threads=2" \
      "voisniff.daemon.threads_per_interface=2" \
      "fileshare.enable=yes"
  fi

  log_info "Enabling:"
  log_info "  SSH on all the interfaces for CE/PRO/Carrier installations"
  log_info "  backup tools on CE/PRO/Carrier installations"
  log_info "Disabling:"
  log_info "  systemd-getty TTYVTDisallocate for vagrant VM (to keep errors on console)"
  
  ngcpcfg set "${CONFIG_YML}" \
    "sshd.listen_addresses.APPEND='0.0.0.0'" \
    "sshd.listen_addresses.APPEND='::'" \
    "sshd.authorized_keys_file='%h/.ssh/authorized_keys %h/.ssh/sipwise_vagrant_key'" \
    "sudo.logging.enable=no" \
    "security.ngcp_panel.scripts.restapi.sslverify=no" \
    "general.production=no" \
    "backuptools.cdrexport_backup.enable=yes" \
    "backuptools.etc_backup.enable=yes" \
    "backuptools.mysql_backup.enable=yes" \
    "systemd.getty.ttyvtdisallocate=no"
}

vm_net_configuration() {
  local host="${1}"

  if ! "${ENABLE_VM_SERVICES}" ; then
    log_info "No need to run vm_net_configuration"
    return
  fi

  log_info "Enabling on host ${host} interface '${EXTERNAL_DEV}' with dhcp, for Vagrant"
  ngcp-network --host="${host}" --set-interface="${EXTERNAL_DEV}" --dhcp=yes

  log_info "Enabling on host ${host} NGCP selfcare and admin interfaces on interface '${EXTERNAL_DEV}' (web_ext and web_int types)"
  ngcp-network --host="${host}" --set-interface="${EXTERNAL_DEV}" --type=web_ext --type=web_int
}
